@@ -39,17 +39,23 @@ describe 'horizon' do
           is_expected.to_not contain_concat(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_cache]')
           is_expected.to contain_concat(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_compress]')
         end
+
+        is_expected.to contain_concat(platforms_params[:config_file]).with(
+          :mode      => '0640',
+          :owner     => platforms_params[:wsgi_user],
+          :group     => platforms_params[:wsgi_group],
+          :show_diff => false
+        )
       }
 
       it 'configures apache' do
         is_expected.to contain_class('horizon::wsgi::apache').with({
-          :servername        => 'some.host.tld',
-          :listen_ssl        => false,
-          :wsgi_processes    => facts[:os_workers],
-          :wsgi_threads      => '1',
-          :extra_params      => {},
-          :redirect_type     => 'permanent',
-          :access_log_format => false,
+          :servername     => 'some.host.tld',
+          :listen_ssl     => false,
+          :wsgi_processes => facts[:os_workers],
+          :wsgi_threads   => '1',
+          :extra_params   => {},
+          :redirect_type  => 'permanent',
         })
       end
 
@@ -60,7 +66,6 @@ describe 'horizon' do
           "LOGOUT_URL = '#{platforms_params[:root_url]}/auth/logout/'",
           "LOGIN_REDIRECT_URL = '#{platforms_params[:root_url]}/'",
           "ALLOWED_HOSTS = ['some.host.tld', ]",
-          "    'identity': 3,",
           'HORIZON_CONFIG["password_autocomplete"] = "off"',
           'HORIZON_CONFIG["images_panel"] = "legacy"',
           "SECRET_KEY = 'elj1IWiLoWHgcyYxFVLj7cM5rGOOxWl0'",
@@ -94,7 +99,7 @@ describe 'horizon' do
     context 'with overridden parameters' do
       before do
         params.merge!({
-          :cache_backend                  => 'horizon.backends.memcached.HorizonMemcached',
+          :cache_backend                  => 'django.core.cache.backends.memcached.MemcachedCache',
           :cache_options                  => {'SOCKET_TIMEOUT' => 1,'SERVER_RETRIES' => 1,'DEAD_RETRY' => 1},
           :cache_server_ip                => '10.0.0.1',
           :django_session_engine          => 'django.contrib.sessions.backends.cache',
@@ -121,7 +126,7 @@ describe 'horizon' do
           :wsgi_processes                 => '30',
           :wsgi_threads                   => '5',
           :secure_cookies                 => true,
-          :api_versions                   => {'identity' => 2.0},
+          :api_versions                   => {'identity' => 3},
           :keystone_multidomain_support   => true,
           :keystone_default_domain        => 'domain.tld',
           :overview_days_range            => 1,
@@ -151,7 +156,7 @@ describe 'horizon' do
           'CSRF_COOKIE_SECURE = True',
           'SESSION_COOKIE_SECURE = True',
           'SESSION_COOKIE_HTTPONLY = True',
-          "    'identity': 2.0,",
+          "    'identity': 3,",
           "OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT = True",
           "OPENSTACK_KEYSTONE_DEFAULT_DOMAIN = 'domain.tld'",
           'HORIZON_CONFIG["password_autocomplete"] = "on"',
@@ -161,7 +166,7 @@ describe 'horizon' do
           "            'DEAD_RETRY': 1,",
           "            'SERVER_RETRIES': 1,",
           "            'SOCKET_TIMEOUT': 1,",
-          "        'BACKEND': 'horizon.backends.memcached.HorizonMemcached',",
+          "        'BACKEND': 'django.core.cache.backends.memcached.MemcachedCache',",
           "        'LOCATION': '10.0.0.1:11211',",
           'SESSION_ENGINE = "django.contrib.sessions.backends.cache"',
           'OPENSTACK_KEYSTONE_URL = "https://keystone.example.com:4682"',
@@ -238,15 +243,17 @@ describe 'horizon' do
       it { is_expected.to contain_exec('refresh_horizon_django_compress') }
     end
 
-    context 'with overridden parameters and IPv6 cache_server_ip array' do
+    context 'with overridden parameters, IPv6 cache_server_ip array and MemcachedCache' do
       before do
         params.merge!({
+          :cache_backend   => 'django.core.cache.backends.memcached.MemcachedCache',
           :cache_server_ip => ['fd12:3456:789a:1::1','fd12:3456:789a:1::2'],
         })
       end
 
       it 'generates local_settings.py' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
+          "        'BACKEND': 'django.core.cache.backends.memcached.MemcachedCache',",
           "        'LOCATION': [ 'inet6:[fd12:3456:789a:1::1]:11211','inet6:[fd12:3456:789a:1::2]:11211', ],",
         ])
       end
@@ -255,7 +262,26 @@ describe 'horizon' do
       it { is_expected.to contain_exec('refresh_horizon_django_compress') }
     end
 
-    context 'with overridden parameters and cache_server_url' do
+    context 'with overridden parameters, IPv6 cache_server_ip array and PyMemcacheCache' do
+      before do
+        params.merge!({
+          :cache_backend   => 'django.core.cache.backends.memcached.PyMemcacheCache',
+          :cache_server_ip => ['fd12:3456:789a:1::1','fd12:3456:789a:1::2'],
+        })
+      end
+
+      it 'generates local_settings.py' do
+        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
+          "        'BACKEND': 'django.core.cache.backends.memcached.PyMemcacheCache',",
+          "        'LOCATION': [ '[fd12:3456:789a:1::1]:11211','[fd12:3456:789a:1::2]:11211', ],",
+        ])
+      end
+
+      it { is_expected.to contain_exec('refresh_horizon_django_cache') }
+      it { is_expected.to contain_exec('refresh_horizon_django_compress') }
+    end
+
+    context 'with overridden parameters and cache_server_url (string)' do
       before do
         params.merge!({
           :cache_server_url => 'redis://:password@10.0.0.1:6379/1',
@@ -272,6 +298,23 @@ describe 'horizon' do
       it { is_expected.to contain_exec('refresh_horizon_django_compress') }
     end
 
+    context 'with overridden parameters and cache_server_url (array)' do
+      before do
+        params.merge!({
+          :cache_server_url => ['192.0.2.1:11211', '192.0.2.2:11211'],
+        })
+      end
+
+      it 'generates local_settings.py' do
+        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
+          "        'LOCATION': ['192.0.2.1:11211','192.0.2.2:11211'],",
+        ])
+      end
+
+      it { is_expected.to contain_exec('refresh_horizon_django_cache') }
+      it { is_expected.to contain_exec('refresh_horizon_django_compress') }
+    end
+
     context 'installs python memcache library when cache_backend is set to memcache' do
       before do
         params.merge!({
@@ -283,19 +326,47 @@ describe 'horizon' do
         is_expected.to contain_package('python-memcache').with(
           :tag    => ['openstack'],
           :name   => platforms_params[:memcache_package],
-         )
+        )
       }
     end
 
     context 'does not install python memcache when manage_memcache_package set to false' do
       before do
-        params.merge!( :cache_backend           => 'django.core.cache.backends.memcached.MemcachedCache',
-                       :manage_memcache_package => false )
+        params.merge!({
+          :cache_backend           => 'django.core.cache.backends.memcached.MemcachedCache',
+          :manage_memcache_package => false
+        })
       end
 
       it { is_expected.not_to contain_package('python-memcache') }
     end
 
+    context 'installs python memcache library when cache_backend is set to pymemcache' do
+      before do
+        params.merge!({
+          :cache_backend => 'django.core.cache.backends.memcached.PyMemcacheCache'
+        })
+      end
+
+      it {
+        is_expected.to contain_package('python-pymemcache').with(
+          :tag    => ['openstack'],
+          :name   => platforms_params[:pymemcache_package],
+        )
+      }
+    end
+
+    context 'does not install python memcache when manage_memcache_package set to false' do
+      before do
+        params.merge!({
+          :cache_backend           => 'django.core.cache.backends.memcached.PyMemcacheCache',
+          :manage_memcache_package => false
+        })
+      end
+
+      it { is_expected.not_to contain_package('python-pymemcache') }
+    end
+
     context 'with custom wsgi options' do
       before do
         params.merge!( :wsgi_processes    => '30',
@@ -456,8 +527,6 @@ describe 'horizon' do
           '# Custom local_settings.py',
           'DEBUG = True',
           "HORIZON_CONFIG = {",
-          "    'dashboards': ('project', 'admin', 'settings',),",
-          "    'default_dashboard': 'project',",
           "    'user_home': 'openstack_dashboard.views.get_user_home',",
           "    'ajax_queue_limit': 10,",
           "    'auto_fade_alerts': {",
@@ -579,13 +648,13 @@ describe 'horizon' do
     context 'with websso enabled' do
       before do
         params.merge!({
-            :websso_enabled => 'True',
+            :websso_enabled        => true,
             :websso_initial_choice => 'acme',
-            :websso_choices => [
+            :websso_choices        => [
               ['oidc', 'OpenID Connect'],
               ['saml2', 'Security Assertion Markup Language'],
             ],
-            :websso_idp_mapping => {
+            :websso_idp_mapping    => {
               'acme_oidc'  => ['acme', 'oidc'],
               'acme_saml2' => ['acme', 'saml2'],
             }
@@ -640,8 +709,6 @@ describe 'horizon' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
           '# Custom local_settings.py',
           "HORIZON_CONFIG = {",
-          "    'dashboards': ('project', 'admin', 'settings',),",
-          "    'default_dashboard': 'project',",
           "    'user_home': 'openstack_dashboard.views.get_user_home',",
           "    'ajax_queue_limit': 10,",
           "    'auto_fade_alerts': {",
@@ -672,8 +739,6 @@ describe 'horizon' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
           '# Custom local_settings.py',
           "HORIZON_CONFIG = {",
-          "    'dashboards': ('project', 'admin', 'settings',),",
-          "    'default_dashboard': 'project',",
           "    'user_home': 'openstack_dashboard.views.get_user_home',",
           "    'ajax_queue_limit': 10,",
           "    'auto_fade_alerts': {",
@@ -703,19 +768,6 @@ describe 'horizon' do
       end
     end
 
-    context 'with upload mode with quotes' do
-      before do
-        params.merge!({
-          :horizon_upload_mode  => '"direct"',
-        })
-      end
-      it 'sets HORIZON_IMAGES_UPLOAD_MODE in local_settings.py' do
-        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-          'HORIZON_IMAGES_UPLOAD_MODE = "direct"',
-        ])
-      end
-    end
-
     context 'with keystone_domain_choices' do
       before do
         params.merge!({
@@ -769,29 +821,38 @@ describe 'horizon' do
         case facts[:osfamily]
         when 'Debian'
           if facts[:operatingsystem] == 'Debian'
-            { :config_file      => '/etc/openstack-dashboard/local_settings.py',
-              :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
-              :package_name     => 'openstack-dashboard-apache',
-              :root_url         => '/horizon',
-              :root_path        => '/var/lib/openstack-dashboard',
-              :memcache_package => 'python3-memcache',
+            { :config_file        => '/etc/openstack-dashboard/local_settings.py',
+              :conf_d_dir         => '/etc/openstack-dashboard/local_settings.d',
+              :package_name       => 'openstack-dashboard-apache',
+              :root_url           => '/horizon',
+              :root_path          => '/var/lib/openstack-dashboard',
+              :memcache_package   => 'python3-memcache',
+              :pymemcache_package => 'python3-pymemcache',
+              :wsgi_user          => 'horizon',
+              :wsgi_group         => 'horizon',
             }
           else
-            { :config_file      => '/etc/openstack-dashboard/local_settings.py',
-              :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
-              :package_name     => 'openstack-dashboard',
-              :root_url         => '/horizon',
-              :root_path        => '/var/lib/openstack-dashboard',
-              :memcache_package => 'python3-memcache',
+            { :config_file        => '/etc/openstack-dashboard/local_settings.py',
+              :conf_d_dir         => '/etc/openstack-dashboard/local_settings.d',
+              :package_name       => 'openstack-dashboard',
+              :root_url           => '/horizon',
+              :root_path          => '/var/lib/openstack-dashboard',
+              :memcache_package   => 'python3-memcache',
+              :pymemcache_package => 'python3-pymemcache',
+              :wsgi_user          => 'horizon',
+              :wsgi_group         => 'horizon',
             }
           end
         when 'RedHat'
-          { :config_file      => '/etc/openstack-dashboard/local_settings',
-            :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
-            :package_name     => 'openstack-dashboard',
-            :root_url         => '/dashboard',
-            :root_path        => '/usr/share/openstack-dashboard',
-            :memcache_package => 'python3-memcached',
+          { :config_file        => '/etc/openstack-dashboard/local_settings',
+            :conf_d_dir         => '/etc/openstack-dashboard/local_settings.d',
+            :package_name       => 'openstack-dashboard',
+            :root_url           => '/dashboard',
+            :root_path          => '/usr/share/openstack-dashboard',
+            :memcache_package   => 'python3-memcached',
+            :pymemcache_package => 'python3-pymemcache',
+            :wsgi_user          => 'apache',
+            :wsgi_group         => 'apache',
           }
         end
       end
