@@ -21,16 +21,14 @@ describe 'horizon::wsgi::apache' do
     context 'with default parameters' do
       it { should contain_class('horizon::params') }
       it { should contain_class('apache') }
-      it { should contain_class('apache::mod::wsgi') }
       it { should contain_file(platforms_params[:httpd_config_file]) }
       it { should contain_package('horizon').with_ensure('present') }
 
       it { should contain_apache__vhost('horizon_vhost').with(
         :servername                  => 'some.host.tld',
         :access_log_file             => 'horizon_access.log',
-        :access_log_format           => false,
         :error_log_file              => 'horizon_error.log',
-        :priority                    => '15',
+        :priority                    => 15,
         :serveraliases               => ['some.host.tld'],
         :docroot                     => '/var/www/',
         :ssl                         => 'false',
@@ -55,7 +53,7 @@ describe 'horizon::wsgi::apache' do
     context 'with overridden parameters' do
       before do
         params.merge!({
-          :priority          => '10',
+          :priority          => 10,
           :redirect_type     => 'temp',
           :wsgi_processes    => '13',
           :wsgi_threads      => '3',
@@ -65,7 +63,6 @@ describe 'horizon::wsgi::apache' do
 
       it { should contain_class('horizon::params') }
       it { should contain_class('apache') }
-      it { should contain_class('apache::mod::wsgi') }
       it { should contain_file(platforms_params[:httpd_config_file]) }
       it { should contain_package('horizon').with_ensure('present') }
 
@@ -131,14 +128,11 @@ describe 'horizon::wsgi::apache' do
         })
       end
 
-      it { should contain_class('apache::mod::ssl') }
-
       it { should contain_apache__vhost('horizon_ssl_vhost').with(
         :servername             => 'some.host.tld',
         :access_log_file        => 'horizon_ssl_access.log',
-        :access_log_format      => false,
         :error_log_file         => 'horizon_ssl_error.log',
-        :priority               => '15',
+        :priority               => 15,
         :serveraliases          => ['some.host.tld'],
         :docroot                => '/var/www/',
         :ssl                    => 'true',
@@ -168,9 +162,8 @@ describe 'horizon::wsgi::apache' do
       it { should contain_apache__vhost('horizon_vhost').with(
         :servername             => 'some.host.tld',
         :access_log_file        => 'horizon_access.log',
-        :access_log_format      => false,
         :error_log_file         => 'horizon_error.log',
-        :priority               => '15',
+        :priority               => 15,
         :serveraliases          => ['some.host.tld'],
         :docroot                => '/var/www/',
         :ssl                    => 'false',
@@ -227,7 +220,7 @@ describe 'horizon::wsgi::apache' do
         params.merge!({
           :extra_params  => {
             'add_listen' => false,
-            'docroot' => '/tmp'
+            'docroot'    => '/tmp'
           },
         })
       end
@@ -236,6 +229,30 @@ describe 'horizon::wsgi::apache' do
         :add_listen => false,
         :docroot    => '/tmp'
       )}
+      it { should contain_apache__vhost('horizon_ssl_vhost').with(
+        :add_listen => false,
+        :docroot    => '/tmp'
+      )}
+    end
+
+    context 'with ssl extra parameters' do
+      before do
+        params.merge!({
+          :extra_params  => {
+            'docroot' => '/root1'
+          },
+          :ssl_extra_params  => {
+            'docroot' => '/root2'
+          },
+        })
+      end
+
+      it { should contain_apache__vhost('horizon_vhost').with(
+        :docroot => '/root1'
+      )}
+      it { should contain_apache__vhost('horizon_ssl_vhost').with(
+        :docroot => '/root2'
+      )}
     end
 
     context 'with root_url set to /' do
@@ -432,25 +449,12 @@ describe 'horizon::wsgi::apache' do
   end
 
   shared_examples 'horizon::wsgi::apache on RedHat' do
-    it { should contain_class('apache::mod::wsgi').with(
-      :wsgi_socket_prefix => '/var/run/wsgi'
+    it { should contain_apache__vhost('horizon_vhost').with(
+      :aliases => [
+        { 'alias' => '/dashboard/static', 'path' => '/usr/share/openstack-dashboard/static' }
+      ],
     )}
 
-    if (Gem::Version.new(Puppet.version) >= Gem::Version.new('4.0'))
-      it { should contain_apache__vhost('horizon_vhost').with(
-        :aliases => [
-          { 'alias' => '/dashboard/static', 'path' => '/usr/share/openstack-dashboard/static' }
-        ],
-      )}
-    else
-      it { should contain_apache__vhost('horizon_vhost').with(
-        :aliases => [
-          ['alias', '/dashboard/static'],
-          ['path', '/usr/share/openstack-dashboard/static']
-        ],
-      )}
-    end
-
     context 'with root_path set to /tmp/horizon' do
       before do
         params.merge!({
@@ -458,38 +462,20 @@ describe 'horizon::wsgi::apache' do
         })
       end
 
-      if (Gem::Version.new(Puppet.version) >= Gem::Version.new('4.0'))
-        it { should contain_apache__vhost('horizon_vhost').with(
-          :aliases => [
-            { 'alias' => '/dashboard/static', 'path' => '/tmp/horizon/static' }
-          ],
-        )}
-      else
-        it { should contain_apache__vhost('horizon_vhost').with(
-          :aliases => [
-            ['alias', '/dashboard/static'],
-            ['path', '/tmp/horizon/static']
-          ],
-        )}
-      end
+      it { should contain_apache__vhost('horizon_vhost').with(
+        :aliases => [
+          { 'alias' => '/dashboard/static', 'path' => '/tmp/horizon/static' }
+        ],
+      )}
     end
   end
 
   shared_examples 'horizon::wsgi::apache on Debian' do
-    if (Gem::Version.new(Puppet.version) >= Gem::Version.new('4.0'))
-      it { should contain_apache__vhost('horizon_vhost').with(
-        :aliases => [
-          { 'alias' => '/horizon/static', 'path' => '/var/lib/openstack-dashboard/static' }
-        ],
-      )}
-    else
-      it { should contain_apache__vhost('horizon_vhost').with(
-        :aliases => [
-          ['alias', '/horizon/static'],
-          ['path', '/var/lib/openstack-dashboard/static']
-        ],
-      )}
-    end
+    it { should contain_apache__vhost('horizon_vhost').with(
+      :aliases => [
+        { 'alias' => '/horizon/static', 'path' => '/var/lib/openstack-dashboard/static' }
+      ],
+    )}
 
     context 'with root_path set to /tmp/horizon' do
       before do
@@ -498,20 +484,11 @@ describe 'horizon::wsgi::apache' do
         })
       end
 
-      if (Gem::Version.new(Puppet.version) >= Gem::Version.new('4.0'))
-        it { should contain_apache__vhost('horizon_vhost').with(
-          :aliases => [
-            { 'alias' => '/horizon/static', 'path' => '/tmp/horizon/static' }
-          ],
-        )}
-      else
-        it { should contain_apache__vhost('horizon_vhost').with(
-          :aliases => [
-            ['alias', '/horizon/static'],
-            ['path', '/tmp/horizon/static']
-          ],
-        )}
-      end
+      it { should contain_apache__vhost('horizon_vhost').with(
+        :aliases => [
+          { 'alias' => '/horizon/static', 'path' => '/tmp/horizon/static' }
+        ],
+      )}
     end
   end
 
